@@ -27,9 +27,9 @@ from drf_spectacular.plumbing import (
     ComponentRegistry, ResolvedComponent, UnableToProceedError, append_meta, build_array_type,
     build_basic_type, build_choice_field, build_examples_list, build_media_type_object,
     build_object_type, build_parameter_type, error, follow_field_source, force_instance, get_doc,
-    get_view_model, is_basic_type, is_field, is_list_serializer, is_patched_serializer,
-    is_serializer, is_trivial_string_variation, resolve_regex_path_parameter, resolve_type_hint,
-    safe_ref, warn,
+    get_type_hints, get_view_model, is_basic_type, is_field, is_list_serializer,
+    is_patched_serializer, is_serializer, is_trivial_string_variation, resolve_regex_path_parameter,
+    resolve_type_hint, safe_ref, warn,
 )
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import OpenApiTypes, build_generic_type
@@ -271,11 +271,11 @@ class AutoSchema(ViewInspector):
             auths.append({})
         return auths
 
-    def get_request_serializer(self):
+    def get_request_serializer(self) -> typing.Any:
         """ override this for custom behaviour """
         return self._get_serializer()
 
-    def get_response_serializers(self):
+    def get_response_serializers(self) -> typing.Any:
         """ override this for custom behaviour """
         return self._get_serializer()
 
@@ -828,7 +828,7 @@ class AutoSchema(ViewInspector):
                     schema['minimum'] = -schema['maximum']
 
     def _map_response_type_hint(self, method):
-        hint = get_override(method, 'field') or typing.get_type_hints(method).get('return')
+        hint = get_override(method, 'field') or get_type_hints(method).get('return')
 
         if is_serializer(hint) or is_field(hint):
             return self._map_serializer_field(force_instance(hint), 'response')
@@ -1078,7 +1078,7 @@ class AutoSchema(ViewInspector):
         if (
             self._is_list_view(serializer)
             and get_override(serializer, 'many') is not False
-            and '200' <= status_code < '300'
+            and ('200' <= status_code < '300' or spectacular_settings.ENABLE_LIST_MECHANICS_ON_NON_2XX)
         ):
             schema = build_array_type(schema)
             paginator = self._get_paginator()
