@@ -38,13 +38,19 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
     # None will default to DRF's AUTHENTICATION_CLASSES
     'SERVE_AUTHENTICATION': None,
 
-    # Dictionary of configurations to pass to the SwaggerUI({ ... })
+    # Dictionary of general configuration to pass to the SwaggerUI({ ... })
     # https://swagger.io/docs/open-source-tools/swagger-ui/usage/configuration/
     'SWAGGER_UI_SETTINGS': {
         'deepLinking': True,
     },
-    'SWAGGER_UI_DIST': '//unpkg.com/swagger-ui-dist@3.44.0',
-    'SWAGGER_UI_FAVICON_HREF': '//unpkg.com/swagger-ui-dist@3.44.0/favicon-32x32.png',
+    # Initialize SwaggerUI with additional OAuth2 configuration.
+    # https://swagger.io/docs/open-source-tools/swagger-ui/usage/oauth2/
+    'SWAGGER_UI_OAUTH2_CONFIG': {},
+
+    # CDNs for for swagger and redoc. You can change the version or even host your
+    # own depending on your requirements.
+    'SWAGGER_UI_DIST': '//unpkg.com/swagger-ui-dist@3.51.0',
+    'SWAGGER_UI_FAVICON_HREF': '//unpkg.com/swagger-ui-dist@3.51.0/favicon-32x32.png',
 
     'REDOC_DIST': '//cdn.jsdelivr.net/npm/redoc@next',
 
@@ -101,6 +107,12 @@ SPECTACULAR_DEFAULTS: Dict[str, Any] = {
     # the order they arrived. Accepts either True, False, or a callable for sort's key arg.
     'SORT_OPERATION_PARAMETERS': True,
 
+    # @extend_schema allows to specify status codes besides 200. This functionality is usually used
+    # to describe error responses, which rarely make use of list mechanics. Therefore, we suppress
+    # listing (pagination and filtering) on non-2XX status codes by default. Toggle this to enable
+    # list responses with ListSerializers/many=True irrespective of the status code.
+    'ENABLE_LIST_MECHANICS_ON_NON_2XX': False,
+
     # Option for turning off error and warn messages
     'DISABLE_ERRORS_AND_WARNINGS': False,
 
