@@ -1,6 +1,6 @@
 import functools
 import inspect
-from typing import Any, Dict, List, Optional, Type, Union
+from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, Union
 
 from rest_framework.fields import Field, empty
 from rest_framework.serializers import Serializer
@@ -181,6 +181,9 @@ class OpenApiResponse(OpenApiSchemaBase):
         self.examples = examples or []
 
 
+F = TypeVar('F', bound=Callable[..., Any])
+
+
 def extend_schema(
         operation_id: Optional[str] = None,
         parameters: Optional[List[Union[OpenApiParameter, _SerializerType]]] = None,
@@ -196,7 +199,7 @@ def extend_schema(
         methods: Optional[List[str]] = None,
         versions: Optional[List[str]] = None,
         examples: Optional[List[OpenApiExample]] = None,
-):
+) -> Callable[[F], F]:
     """
     Decorator mainly for the "view" method kind. Partially or completely overrides
     what would be otherwise generated by drf-spectacular.
@@ -367,7 +370,7 @@ def extend_schema(
 def extend_schema_field(
         field: Union[_SerializerType, Field, OpenApiTypes, Dict],
         component_name: Optional[str] = None
-):
+) -> Callable[[F], F]:
     """
     Decorator for the "field" kind. Can be used with ``SerializerMethodField`` (annotate the actual
     method) or with custom ``serializers.Field`` implementations.
@@ -394,7 +397,7 @@ def extend_schema_serializer(
         exclude_fields: Optional[List[str]] = None,
         deprecate_fields: Optional[List[str]] = None,
         examples: Optional[List[OpenApiExample]] = None,
-):
+) -> Callable[[F], F]:
     """
     Decorator for the "serializer" kind. Intended for overriding default serializer behaviour that
     cannot be influenced through :func:`@extend_schema <.extend_schema>`.
@@ -420,7 +423,7 @@ def extend_schema_serializer(
     return decorator
 
 
-def extend_schema_view(**kwargs):
+def extend_schema_view(**kwargs) -> Callable[[F], F]:
     """
     Convenience decorator for the "view" kind. Intended for annotating derived view methods that
     are are not directly present in the view (usually methods like ``list`` or ``retrieve``).
